@@ -1,7 +1,7 @@
-parLapplySB <- 
+parLapplySB <-
 function(cl, x, size = 1, fun, ...)
 {
-    require(snow)
+    requireNamespace("snow")
     fun <- match.fun(fun)
     s <- clusterSplitSB(cl, x, size)
     id <- clusterSplitSB(cl, 1:length(x), size)
